@@ -8,8 +8,7 @@ import logging
 
 from .article import Article, ArticleException
 from .configuration import Configuration
-from .mthreading import NewsPool
-from .utils import get_languages, get_available_languages, fulltext
+from .utils import get_languages, fulltext
 from .version import __version__
 
 __title__ = 'stimson-web-scraper'
@@ -19,8 +18,6 @@ __copyright__ = 'Copyright 2014, Lucas Ou-Yang'
 __maintainer__ = "The Stimson Center"
 __maintainer_email = "cooper@pobox.com"
 
-news_pool = NewsPool()
-
 
 class NullHandler(logging.Handler):
     def emit(self, record):
