@@ -14,12 +14,12 @@ sys.path.append(os.path.normpath(os.path.join(SCRIPT_DIR, PACKAGE_PARENT)))
 # noinspection PyPep8
 from scraper import Article
 # noinspection PyPep8
-from scraper.utils import get_available_language_codes
+from scraper.utils import get_language_codes
 
 
 @click.command()
 @click.option('--language', '-l', default='en', help='Language in which the text is written',
-              type=click.Choice(get_available_language_codes()))
+              type=click.Choice(get_language_codes()))
 @click.option('--url', '-u', help='URL to parse', required=True)
 def parse(url, language):
     article = Article(url, language=language)
