@@ -29,8 +29,6 @@ class Configuration(object):
         Modify any of these Article / Source properties
         TODO: Have a separate ArticleConfig and SourceConfig extend this!
         """
-        self.MIN_WORD_COUNT = 300  # num of word tokens in text
-        self.MIN_SENT_COUNT = 7  # num of sentence tokens
         self.MAX_TITLE = 200  # num of chars
         self.MAX_TEXT = 100000  # num of chars
         self.MAX_KEYWORDS = 35  # num of strings in list
