@@ -6,7 +6,6 @@ Hence, we have an entire module dedicated to them.
 
 import logging
 import re
-from base64 import b64encode, b64decode
 from urllib.parse import parse_qs, urljoin, urlparse, urlsplit, urlunsplit
 
 from tldextract import tldextract
@@ -290,32 +289,6 @@ def get_path(abs_url, **kwargs):
     return urlparse(abs_url, **kwargs).path
 
 
-def is_abs_url(url):
-    """
-    this regex was brought to you by django!
-    """
-    regex = re.compile(
-        r'^(?:http|ftp)s?://'  # http:// or https://
-        r'(?:(?:[A-Z0-9](?:[A-Z0-9-]{0,61}[A-Z0-9])?\.)+(?:[A-Z]{2,6}\.?|[A-Z0-9-]{2,}\.?)|'  # domain...
-        r'localhost|'  # localhost...
-        r'\d{1,3}\.\d{1,3}\.\d{1,3}\.\d{1,3}|'  # ...or ipv4
-        r'\[?[A-F0-9]*:[A-F0-9:]+\]?)'  # ...or ipv6
-        r'(?::\d+)?'  # optional port
-        r'(?:/?|[/?]\S+)$', re.IGNORECASE)
-
-    c_regex = re.compile(regex)
-    return c_regex.search(url) is not None
-
-
-def b64_encode(url):
-    clean_url = url.rstrip().encode()
-    encoded = b64encode(clean_url)
-    decoded_url = b64decode(encoded)
-    if decoded_url != clean_url:
-        raise Exception('Error encoding url %s' % url)
-    return encoded.decode("utf-8")
-
-
 def extract_domain(url):
     # extract the tld (top level domain)
     tld_dat = tldextract.extract(url)
