@@ -1,10 +1,7 @@
-import logging
 import os
 import time
 
 import pytest
-from flask import Flask
-from flask_restful import Api
 
 
 # noinspection PyProtectedMember
@@ -13,13 +10,6 @@ def fixture_directory():
     return os.path.join(os.path.dirname(__file__), "fixtures")
 
 
-@pytest.fixture(scope='function')
-def app():
-    app = Flask("test")
-    app.logger.setLevel(logging.DEBUG)
-    return app
-
-
 def mock_resource_with(filename, resource_type):
     """
     Mocks an HTTP request by pulling text from a pre-downloaded file
